==> spring-boot-ext-1.2.149-sources.jar: cn/com/duibaboot/ext/autoconfigure/javaagent/core/PluginCfg.java <==
package cn.com.duibaboot.ext.autoconfigure.javaagent.core;

import cn.com.duibaboot.ext.autoconfigure.javaagent.core.exception.IllegalPluginDefineException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;


public enum PluginCfg {
    INSTANCE;

    private final Logger logger =  LoggerFactory.getLogger(PluginCfg.class.getName());

    private List<PluginDefine> pluginClassList = new ArrayList<PluginDefine>();

    void load(InputStream input) throws IOException {
        try {
            BufferedReader reader = new BufferedReader(new InputStreamReader(input));
            String pluginDefine = null;
            while ((pluginDefine = reader.readLine()) != null) {
                try {
                    if (pluginDefine == null || pluginDefine.trim().length() == 0) {
                        continue;
                    }
                    PluginDefine plugin = PluginDefine.build(pluginDefine);
                    if (plugin.enable()) {
                        pluginClassList.add(plugin);
                    }
                } catch (IllegalPluginDefineException e) {
                    logger.error(String.format("Failed to format plugin(%s) define.", pluginDefine),e);
                }
            }
        } finally {
            input.close();
        }
    }

    public List<PluginDefine> getPluginClassList() {
        return pluginClassList;
    }

}

==> spring-boot-ext-1.2.232-sources.jar: cn/com/duibaboot/ext/autoconfigure/javaagent/core/PluginCfg.java <==
package cn.com.duibaboot.ext.autoconfigure.javaagent.core;

import cn.com.duibaboot.ext.autoconfigure.javaagent.core.exception.IllegalPluginDefineException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;


public enum PluginCfg {
    INSTANCE;

    private final Logger logger =  LoggerFactory.getLogger(PluginCfg.class.getName());

    private List<PluginDefine> pluginClassList = new ArrayList<>();

    void load(InputStream input) throws IOException {
        try(BufferedReader reader = new BufferedReader(new InputStreamReader(input))){
            String pluginDefine;
            while ((pluginDefine = reader.readLine()) != null) {
                try {
                    if (pluginDefine.trim().length() == 0) {
                        continue;
                    }
                    PluginDefine plugin = PluginDefine.build(pluginDefine);
                    if (plugin.enable()) {
                        pluginClassList.add(plugin);
                    }
                } catch (IllegalPluginDefineException e) {
                    logger.error(String.format("Failed to format plugin(%s) define.", pluginDefine),e);
                }
            }
        } finally {
            input.close();
        }
    }

    public List<PluginDefine> getPluginClassList() {
        return pluginClassList;
    }

}
